@@ -65,7 +65,6 @@ class StopwatchKafka(Stopwatch):
             self.kafka_parition = kafka_parition
             self.kafka_conf = {
                 "bootstrap.servers": bootstrap_servers,
-                "value.serializer": lambda x: dumps(x).encode(encoding),
             }
             self.producer = SerializingProducer(self.kafka_conf)
             if metadata is None:
@@ -81,15 +80,15 @@ class StopwatchKafka(Stopwatch):
     def __exit__(self, *args):
         super().__exit__()
         try:
-            # NOTE: edit this or make it dynamic for extra data to be sent over to topic???
             time_data = {
                 "time_taken": self.time_taken,
                 "timestamp": datetime.utcnow().isoformat(),
+                **self.metadata
             }
             # async operation
             self.producer.produce(
                 topic=self.kafka_topic,
-                value=time_data,
+                value=dumps(time_data).encode('utf-8'),
                 key=self.kafka_keys,
                 headers=self.kafka_headers,
                 partition=self.kafka_parition,
